@@ -158,8 +158,6 @@ FEATURE_FLAGS = [
       "'typing.Tuple' compatibility.")),
     ("--strict-parameter-checks", False,
      "Enable exhaustive checking of function parameter types."),
-    ("--enable-nested-classes", True,
-     "Enable support for nested classes in .py files."),
     ("--strict-primitive-comparisons", False,
      "Emit errors for comparisons between incompatible primitive types."),
     ("--overriding-default-value-checks", False,
