@@ -15,10 +15,11 @@ import unittest
 class SerializeAstTest(test_base.UnitTest):
 
   def _store_ast(
-      self, temp_dir, module_name, pickled_ast_filename, ast=None, loader=None):
+      self, temp_dir, module_name, pickled_ast_filename, ast=None, loader=None,
+      is_package=False):
     if not (ast and loader):
       ast, loader = self._get_ast(temp_dir=temp_dir, module_name=module_name)
-    serialize_ast.StoreAst(ast, pickled_ast_filename)
+    serialize_ast.StoreAst(ast, pickled_ast_filename, is_package=is_package)
     module_map = {name: module.ast
                   for name, module in loader._modules.items()}
 
@@ -265,7 +266,7 @@ class SerializeAstTest(test_base.UnitTest):
       pickled_ast_filename = os.path.join(d.path, "module1.pyi.pickled")
 
       module_map = self._store_ast(
-          d, original_module_name, pickled_ast_filename)
+          d, original_module_name, pickled_ast_filename, is_package=True)
       serializable_ast = pytd_utils.LoadPickle(pickled_ast_filename)
 
       expected_name = "module1"
