@@ -1,7 +1,6 @@
 """Tests for pytype_source_utils.py."""
 
 import os
-import sys
 
 from pytype import pytype_source_utils
 
@@ -31,19 +30,6 @@ class PytypeSourceUtilsTest(unittest.TestCase):
     self.assertIn("_ctypes.pytd", l)
     self.assertIn("collections/__init__.pytd", l)
 
-  def test_get_custom_python_exe37(self):
-    exe = pytype_source_utils.get_custom_python_exe((3, 7))
-    if sys.version_info[:2] == (3, 7):
-      self.assertIsNone(exe)
-    elif os.path.exists(pytype_source_utils.CUSTOM_PY37_EXE):
-      self.assertIn("3.7", exe)
-    else:
-      self.assertIsNone(exe)
-
-  def test_get_custom_python_exe_host(self):
-    exe = pytype_source_utils.get_custom_python_exe(sys.version_info[:2])
-    self.assertIsNone(exe)
-
 
 if __name__ == "__main__":
   unittest.main()
